4Suite API Documentation: Ft.Lib.TestSuite.TestFunction

4Suite™ API Documentation

# ► Module Ft.Lib.TestSuite.TestFunction

Provides the TestFunction class for wrapping functions.

    Copyright 2002 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: TestFunction

## Classes

class TestFunction(Ft.Lib.TestSuite.TestObject.TestObject)
  A test object that wraps a testing function.

  ### Methods

  __init__(self, function)
    Overrides: __init__ from class TestObject

  ### Methods inherited from class Ft.Lib.TestSuite.TestObject.TestObject

  __str__, getModes, getTests, run, showTests

  ### Members inherited from class Ft.Lib.TestSuite.TestObject.TestObject

  modes, tests